climind.web package
===================

Submodules
----------

climind.web.dashboard module
----------------------------

.. automodule:: climind.web.dashboard
   :members:
   :undoc-members:
   :show-inheritance:

climind.web.extract\_from\_word module
--------------------------------------

.. automodule:: climind.web.extract_from_word
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: climind.web
   :members:
   :undoc-members:
   :show-inheritance:
